@@ -8,27 +8,18 @@ class media(base):
 
     def upload(self, type: str, file: str, filename: str = "data.xlsx"):
         api_name = "media/upload"
-        params = {
-            "type": type
-        }
+        params = {"type": type}
         # files = {type: open(file, "rb")}
         files = {"file": (f"{filename}.xlsx", open(file, "rb"))}
         response = self.request(
-            api_name=api_name,
-            method="POST",
-            params=params,
-            files=files
+            api_name=api_name, method="POST", params=params, files=files
         )
-        logger.debug(response)
+        
         return response
 
     def uploadimg(self, file: str):
         api_name = "media/uploadimg"
         files = {"image": open(file, "rb")}
-        response = self.request(
-            api_name=api_name,
-            method="POST",
-            files=files
-        )
-        logger.debug(response)
+        response = self.request(api_name=api_name, method="POST", files=files)
+        
         return response
